\name{rpucor}
\alias{rpucor}
\alias{rpuCor}
\alias{rpucor.default}
\concept{correlation coefficient}
\concept{Kendall's tau}
\title{Kendall's Tau-b Correlation Coefficient on GPU}

\description{
This function computes the correlation matrix of two multivariate statistics.
}

\usage{
\method{rpucor}{default}(x, y = NULL, 
    use = "everything",
    method = c("pearson", "spearman", "kendall", "gamma"), \dots)
}

\arguments{
    \item{x}{a numeric vector, matrix or data frame. } 

    \item{y}{a vector, matrix or data frame with compatible dimensions to 'x'. 
        The default 'NULL' value is equivalent to 'y = x'. } 

    \item{use}{a string representing the method to handle missing values.  
        Currently supported values are: \code{"everything"}(default), 
        \code{"all.obs"}, \code{"complete.obs"}, \code{"na.or.complete"}, or 
        \code{"pairwise.complete.obs"}.}

    \item{method}{a string representing the name of the correlation to be
        computed.  The supported values are: \code{"pearson"}(default), 
        \code{"spearman"}, \code{"kendall"}, and \code{"gamma"}.}
        
    \item{\dots}{further arguments to be passed to or from methods.}
}

\details{
    Perform the Kendall correlation with GPU using the rpudplus add-on for rpud. 
    The Pearson and Spearman correlation are just stubs that invoke the default implementation of R.
    In absense of rpudplus, rpud computes the Kendall correlation also with the stock R implementation, 
    and there will be no speed gain.
}

\value{
    The correlation matrix of the input statistics.
    An attribute named \code{"method"} contains the name of the correlation, 
    and another attribute named \code{"use"} contains the method to handle missing values.
}

\seealso{
    cor, gpuCor
}

\examples{
\dontrun{

num <- 5
dim1 <- 6
dim2 <- 8
x <- matrix(runif(num*dim1), num, dim1)
y <- matrix(runif(num*dim2), num, dim2)
rpucor(x, y, method = "kendall")

# introduce missing values
x[3,5] <- NA
y[4,1] <- NA
rpucor(x, y, method = "kendall", use="pairwise.complete.obs")

}}

\keyword{multivariate}
\keyword{correlation}


